@@ -92,6 +92,7 @@ class AidotClient:
             self.password = token[CONF_PASSWORD]
             self._region = token[CONF_REGION]
             self.country_name = token[CONF_COUNTRY]
+            self._base_url = f"https://prod-{self._region}-api.arnoo.com/v17"
 
     def set_token_fresh_cb(self, callback) -> None:
         self._token_fresh_cb = callback
@@ -151,7 +152,7 @@ class AidotClient:
                 self._token_fresh_cb()
             return response_data
         except aiohttp.ClientError as e:
-            _LOGGER.info(f"async_refresh_token ClientError {e}")
+            _LOGGER.info(f"async_refresh_token ClientError {e} {response_data}")
             if response_data[CONF_CODE] == ServerErrorCode.LOGIN_INVALID:
                 raise AidotAuthFailed
             return None
@@ -176,7 +177,7 @@ class AidotClient:
             response.raise_for_status()
             return response_data
         except aiohttp.ClientError as e:
-            _LOGGER.info(f"async_get ClientError {e}")
+            _LOGGER.info(f"async_get ClientError {e} {response_data}")
             code = response_data.get(CONF_CODE)
             if code == ServerErrorCode.TOKEN_EXPIRED:
                 try:
